From 9c9382e6949e1366c6adb502b7aacae2c11023f7 Mon Sep 17 00:00:00 2001
From: tbrehm <t.brehm@ispconfig.org>
Date: Thu, 08 Sep 2011 09:42:04 -0400
Subject: [PATCH] Fixed: FS#1709 - Wrong message "Your hard-disk space is going full" in the "Monitor -> Show Disk Usage"

---
 interface/web/sites/ajax_get_ip.php |   11 ++++-------
 1 files changed, 4 insertions(+), 7 deletions(-)

diff --git a/interface/web/sites/ajax_get_ip.php b/interface/web/sites/ajax_get_ip.php
index 57e5b77..0d3227b 100644
--- a/interface/web/sites/ajax_get_ip.php
+++ b/interface/web/sites/ajax_get_ip.php
@@ -31,11 +31,8 @@
 require_once('../../lib/config.inc.php');
 require_once('../../lib/app.inc.php');
 
-// Checking module permissions
-if(!stristr($_SESSION["s"]["user"]["modules"],'sites')) {
-	header("Location: ../index.php");
-	exit;
-}
+//* Check permissions for module
+$app->auth->check_module_permissions('sites');
 
 $server_id = intval($_GET["server_id"]);
 
@@ -44,11 +41,11 @@
 	$sql = "SELECT ip_address FROM server_ip WHERE server_id = $server_id";
 	$ips = $app->db->queryAllRecords($sql);
 	// $ip_select = "<option value=''></option>";
-	$ip_select = "";
+	$ip_select = "*";
 	if(is_array($ips)) {
 		foreach( $ips as $ip) {
 			//$selected = ($ip["ip_address"] == $this->dataRecord["ip_address"])?'SELECTED':'';
-			$ip_select .= "<option value='$ip[ip_address]'>$ip[ip_address]</option>\r\n";
+			$ip_select .= "#$ip[ip_address]";
 		}
 	}
 	unset($tmp);

--
Gitblit v1.9.1